@@ -112,6 +112,7 @@ LOCAL int scgo_amerge		__PR((char *path, char *readedlink,
 LOCAL	void	sglog		__PR((const char *fmt, ...));
 
 #include <vadefs.h>
+#include "oexcl.h"
 
 /* VARARGS1 */
 #ifdef	PROTOTYPES
@@ -267,7 +268,7 @@ openbydev:
 			starget,
 			slun;
 
-		f = open(device, O_RDWR | O_NONBLOCK);
+		f = openexcl(device, O_RDWR | O_NONBLOCK);
 
 		if (f < 0) {
 			if (scgp->errstr)
