@@ -1,4 +1,4 @@
-/* @(#)filemopen.c	1.2 04/03/07 Copyright 1986, 1995-2004 J. Schilling */
+/* @(#)filemopen.c	1.3 04/08/08 Copyright 1986, 1995-2004 J. Schilling */
 /*
  *	Copyright (c) 1986, 1995-2004 J. Schilling
  */
@@ -18,7 +18,7 @@
  * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include "io.h"
+#include "schilyio.h"
 
 EXPORT FILE *
 #ifdef	PROTOTYPES
