@@ -1,4 +1,4 @@
-/* @(#)filemopen64.c	1.1 04/03/05 Copyright 2000-2004 J. Schilling */
+/* @(#)filemopen64.c	1.2 04/08/08 Copyright 2000-2004 J. Schilling */
 /*
  *	Copyright (c) 2000-2004 J. Schilling
  */
@@ -20,7 +20,7 @@
 
 #define	USE_LARGEFILES
 
-#include "io.h"
+#include "schilyio.h"
 
 /*#if	_LFS_LARGEFILE*/
 #ifdef	HAVE_LARGEFILES
