@@ -32,8 +32,11 @@
 
 #include "Toc.h"
 #include "util.h"
+#include "log.h"
 #include "TrackDataList.h"
 #include "CdTextItem.h"
+#include "CueParser.h"
+#include "FormatConverter.h"
 
 #ifdef UNIXWARE
 extern "C" {
@@ -42,12 +45,11 @@ extern "C" {
 #endif
 
 extern Toc *parseToc(FILE *fp, const char *filename);
-extern Toc *parseCue(FILE *fp, const char *filename);
 
 Toc::Toc() : length_(0)
 {
   tocType_ = CD_DA;
-  nofTracks_ = 0;
+  nofTracks_ = 0; firstTrackNo_ = 0;
   tracks_ = lastTrack_ = NULL;
 
   catalogValid_ = 0;
@@ -62,6 +64,7 @@ Toc::Toc(const Toc &obj) : length_(0), cdtext_(obj.cdtext_)
     memcpy(catalog_, obj.catalog_, 13);
 
   nofTracks_ = 0;
+  firstTrackNo_ = obj.firstTrackNo_;
   tracks_ = lastTrack_ = NULL;
 
   // copy all tracks
@@ -138,7 +141,7 @@ Toc *Toc::read(const char *filename)
   const char *p;
 
   if ((fp = fopen(filename, "r")) == NULL) {
-    message(-2, "Cannot open toc file '%s' for reading: %s",
+    log_message(-2, "Cannot open toc file '%s' for reading: %s",
 	    filename, strerror(errno));
     return NULL;
   }
@@ -150,14 +153,24 @@ Toc *Toc::read(const char *filename)
 
   fclose(fp);
 
-  /*
-  if (ret != NULL)
-    ret->print(cout);
-    */
-
   return ret;
 }
 
+bool Toc::resolveFilenames(const char* filename)
+{
+  // Resolve all relative filenames to absoluate paths wrt to the toc
+  // file current directory.
+  std::string path = filename;
+  path = path.substr(0, path.rfind('/'));
+  if (path.empty()) path = ".";
+
+  for (TrackEntry* t = tracks_; t != NULL; t = t->next)
+    if (!t->track->resolveFilename(path.c_str()))
+      return false;
+
+  return true;
+}
+
 // Writes toc to file with given name.
 // Return: 0: OK
 //         1: error occured
@@ -170,7 +183,7 @@ int Toc::write(const char *filename) const
   std::ofstream out(filename);
 
   if (!out) {
-    message(-2, "Cannot open file \"%s\" for writing: %s", filename,
+    log_message(-2, "Cannot open file \"%s\" for writing: %s", filename,
 	    strerror(errno));
     return 1;
   }
@@ -180,12 +193,12 @@ int Toc::write(const char *filename) const
   return 0;
 }
 
-bool Toc::write(int fd) const
+bool Toc::write(int fd, bool conversions) const
 {
     assert(fd);
 
     std::ostringstream oss(std::ostringstream::out);
-    print(oss);
+    print(oss, conversions);
 
     std::string ossstr = oss.str();
     const char* content = ossstr.c_str();
@@ -207,6 +220,17 @@ int Toc::check() const
   return ret;
 }
 
+bool Toc::recomputeLength()
+{
+  for (TrackEntry* t = tracks_; t; t = t->next) {
+    if (!t->track->recomputeLength())
+      return false;
+  }
+
+  update();
+  return true;
+}
+
 // Sets catalog number. 's' must be a string of 13 digits.
 // return: 0: OK
 //         1: illegal catalog string
@@ -254,7 +278,7 @@ const char *Toc::catalog() const
 }
 
 // writes contents in TOC file syntax
-void Toc::print(std::ostream &out) const
+void Toc::print(std::ostream &out, bool conversions) const
 {
   int i;
   TrackEntry *t;
@@ -273,11 +297,30 @@ void Toc::print(std::ostream &out) const
 
   for (t = tracks_, i = 1; t != NULL; t = t->next, i++) {
     out << "\n// Track " << i << "\n";
-    t->track->print(out);
+    t->track->print(out, conversions);
     out << std::endl;
   }
 }
 
+bool Toc::convertFilesToWav()
+{
+  FormatSupport::Status status = formatConverter.convert(this);
+
+  return (status == FormatSupport::FS_SUCCESS);
+}
+
+void Toc::collectFiles(std::set<std::string>& set)
+{
+  for (TrackEntry* t = tracks_; t != NULL; t = t->next)
+    t->track->collectFiles(set);
+}
+
+void Toc::markFileConversion(const char* src, const char* dst)
+{
+  for (TrackEntry* t = tracks_; t != NULL; t = t->next)
+    t->track->markFileConversion(src, dst);
+}
+
 // find track entry that contains given sample number
 // return: found track entry or 'NULL' if sample is out of range
 Toc::TrackEntry *Toc::findTrack(unsigned long sample) const
@@ -661,6 +704,15 @@ int Toc::addPregap(long lba)
   return 0;
 }
 
+void Toc::fixLengths()
+{
+  TrackEntry* te;
+  int i;
+
+  for (i = 0 , te = tracks_; te; te = te->next, i++) {
+    printf("%d : Track %d\n", i, te->trackNr);
+  }
+}
 
 void Toc::checkConsistency()
 {
@@ -670,16 +722,16 @@ void Toc::checkConsistency()
   for (run = tracks_; run != NULL; last = run, run = run->next) {
     cnt++;
     if (run->pred != last) 
-      message(-3, "Toc::checkConsistency: wrong pred pointer.");
+      log_message(-3, "Toc::checkConsistency: wrong pred pointer.");
 
     run->track->checkConsistency();
   }
 
   if (last != lastTrack_)
-    message(-3, "Toc::checkConsistency: wrong last pointer.");
+    log_message(-3, "Toc::checkConsistency: wrong last pointer.");
 
   if (cnt != nofTracks_)
-    message(-3, "Toc::checkConsistency: wrong sub track counter.");
+    log_message(-3, "Toc::checkConsistency: wrong sub track counter.");
 }
 
 
@@ -865,7 +917,7 @@ void Toc::addCdTextItem(int trackNr, CdTextItem *item)
     TrackEntry *track = findTrackByNumber(trackNr);
 
     if (track == NULL) {
-      message(-3, "addCdTextItem: Track %d is not available.", trackNr);
+      log_message(-3, "addCdTextItem: Track %d is not available.", trackNr);
       return;
     }
 
@@ -884,7 +936,7 @@ void Toc::removeCdTextItem(int trackNr, CdTextItem::PackType type, int blockNr)
     TrackEntry *track = findTrackByNumber(trackNr);
 
     if (track == NULL) {
-      message(-3, "addCdTextItem: Track %d is not available.", trackNr);
+      log_message(-3, "addCdTextItem: Track %d is not available.", trackNr);
       return;
     }
 
@@ -960,9 +1012,9 @@ int Toc::checkCdTextData() const
 
       if (l - 1 != last) {
 	if (last == -1)
-	  message(-2, "CD-TEXT: Language number %d: Language numbers must start at 0.", l);
+	  log_message(-2, "CD-TEXT: Language number %d: Language numbers must start at 0.", l);
 	else
-	  message(-2, "CD-TEXT: Language number %d: Language numbers are not continuously used.", l);
+	  log_message(-2, "CD-TEXT: Language number %d: Language numbers are not continuously used.", l);
 
 	if (err < 2)
 	  err = 2;
@@ -973,7 +1025,7 @@ int Toc::checkCdTextData() const
   }
 
   if (genreCnt > 0 && genreCnt != languageCnt) {
-    message(-1, "CD-TEXT: %s field not defined for all languages.",
+    log_message(-1, "CD-TEXT: %s field not defined for all languages.",
 	    CdTextItem::packType2String(1, CdTextItem::CDTEXT_GENRE));
     if (err < 1)
       err = 1;
@@ -1016,54 +1068,54 @@ int Toc::checkCdTextData() const
     }
 
     if (titleCnt > 0 && titleCnt != nofTracks_ + 1) {
-      message(-2, "CD-TEXT: Language %d: %s field not defined for all tracks or disk.",
+      log_message(-2, "CD-TEXT: Language %d: %s field not defined for all tracks or disk.",
 	      l, CdTextItem::packType2String(1, CdTextItem::CDTEXT_TITLE));
       if (err < 2)
 	err = 2;
     }
     else if (titleCnt == 0) {
-      message(-1, "CD-TEXT: Language %d: %s field is not defined.",
+      log_message(-1, "CD-TEXT: Language %d: %s field is not defined.",
 	      l, CdTextItem::packType2String(1, CdTextItem::CDTEXT_TITLE));
       if (err < 1)
 	err = 1;
     }
 
     if (performerCnt > 0 && performerCnt != nofTracks_ + 1) {
-      message(-2, "CD-TEXT: Language %d: %s field not defined for all tracks or disk.",
+      log_message(-2, "CD-TEXT: Language %d: %s field not defined for all tracks or disk.",
 	      l, CdTextItem::packType2String(1, CdTextItem::CDTEXT_PERFORMER));
       if (err < 2)
 	err = 2;
     }
     else if (performerCnt == 0) {
-      message(-1, "CD-TEXT: Language %d: %s field is not defined.",
+      log_message(-1, "CD-TEXT: Language %d: %s field is not defined.",
 	      l, CdTextItem::packType2String(1, CdTextItem::CDTEXT_PERFORMER));
       if (err < 1)
 	err = 1;
     }
 
     if (songwriterCnt > 0 && songwriterCnt != nofTracks_ + 1) {
-      message(-2, "CD-TEXT: Language %d: %s field not defined for all tracks or disk.",
+      log_message(-2, "CD-TEXT: Language %d: %s field not defined for all tracks or disk.",
 	      l, CdTextItem::packType2String(1, CdTextItem::CDTEXT_SONGWRITER));
       if (err < 2)
 	err = 2;
     }
 
     if (composerCnt > 0 && composerCnt != nofTracks_ + 1) {
-      message(-2, "CD-TEXT: Language %d: %s field not defined for all tracks or disk.",
+      log_message(-2, "CD-TEXT: Language %d: %s field not defined for all tracks or disk.",
 	      l, CdTextItem::packType2String(1, CdTextItem::CDTEXT_COMPOSER));
       if (err < 2)
 	err = 2;
     }
 
     if (arrangerCnt > 0 && arrangerCnt != nofTracks_ + 1) {
-      message(-2, "CD-TEXT: Language %d: %s field not defined for all tracks or disk.",
+      log_message(-2, "CD-TEXT: Language %d: %s field not defined for all tracks or disk.",
 	      l, CdTextItem::packType2String(1, CdTextItem::CDTEXT_ARRANGER));
       if (err < 2)
 	err = 2;
     }
 
     if (messageCnt > 0 && messageCnt != nofTracks_ + 1) {
-      message(-2, "CD-TEXT: Language %d: %s field not defined for all tracks or disk.",
+      log_message(-2, "CD-TEXT: Language %d: %s field not defined for all tracks or disk.",
 	      l, CdTextItem::packType2String(1, CdTextItem::CDTEXT_MESSAGE));
       if (err < 2)
 	err = 2;
@@ -1072,7 +1124,7 @@ int Toc::checkCdTextData() const
     if ((isrcCnt > 0 && isrcCnt != nofTracks_) ||
 	(isrcCnt == 0 &&
 	 cdtext_.getPack(l, CdTextItem::CDTEXT_UPCEAN_ISRC) != NULL)) {
-      message(-2, "CD-TEXT: Language %d: %s field not defined for all tracks.",
+      log_message(-2, "CD-TEXT: Language %d: %s field not defined for all tracks.",
 	      l, CdTextItem::packType2String(1, CdTextItem::CDTEXT_UPCEAN_ISRC));
       if (err < 2)
 	err = 2;
@@ -1400,3 +1452,8 @@ long TocReader::readSamples(Sample *buf, long len)
  
   return nread;
 }
+
+const char* TocReader::curFilename()
+{
+    return reader.curFilename();
+}
